"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.filesProcessor = void 0;
const path = __importStar(require("path"));
const svgo_1 = require("svgo");
const code_snippet_generators_1 = require("../generators/code-snippet-generators");
const file_helpers_1 = require("../helpers/file-helpers");
const logger_1 = require("../helpers/logger");
const regex_helpers_1 = require("../helpers/regex-helpers");
const filesProcessor = (conversionOptions) => __awaiter(void 0, void 0, void 0, function* () {
    const { prefix, delimiter, interfaceName, srcFiles, svgoConfig, namePrefix } = conversionOptions;
    const filePaths = yield (0, regex_helpers_1.getFilePathsFromRegex)(srcFiles);
    if (!filePaths.length) {
        throw `No SVG files found for ${srcFiles}`;
    }
    // Using Promise.all we are making all files be processed in parallel as they have no dependency on each other
    let svgDefinitions = yield Promise.all(filePaths.map((filePath) => __awaiter(void 0, void 0, void 0, function* () {
        let svgDefinition = null;
        const fileNameWithEnding = path.basename(filePath).replace(`'`, '');
        const [filenameWithoutEnding, extension] = fileNameWithEnding.split('.');
        if (extension === 'svg') {
            const rawSvg = yield (0, file_helpers_1.extractSvgContent)(filePath);
            logger_1.Logger.verboseInfo(`optimize svg: ${fileNameWithEnding}`);
            const optimizedSvg = yield (0, svgo_1.optimize)(rawSvg, Object.assign({ path: filePath }, svgoConfig));
            const variableName = (0, code_snippet_generators_1.generateVariableName)(prefix, filenameWithoutEnding);
            const typeName = (0, code_snippet_generators_1.generateTypeName)(filenameWithoutEnding, delimiter, namePrefix);
            svgDefinition = {
                typeName,
                prefix,
                variableName,
                interfaceName,
                data: optimizedSvg.data,
                filenameWithoutEnding
            };
        }
        return svgDefinition;
    })));
    return svgDefinitions.filter(svgDefinition => svgDefinition);
});
exports.filesProcessor = filesProcessor;
//# sourceMappingURL=shared.converter.js.map